const fs = require("fs");
const minify = require("minify");
const options = {
    js: {
        ecma: 5,
        compress: false,
        mangle: false,
        format: { quote_style: 1 },
        keep_fnames: true,
    },
};

const defaultConfig = JSON.parse(fs.readFileSync("src/config.js"));
const defaultAutoconfig = JSON.parse(fs.readFileSync("src/compounding/autoconfig.json"));
const defaultAutoconfigManualPairs = JSON.parse(fs.readFileSync("src/compounding_manual-pairs/autoconfig.json"));
const defaultAutoconfigNoCompounding = JSON.parse(fs.readFileSync("src/noCompounding/autoconfig.json"));

const outputVariations = [
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH", "BNB"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-BNB,USDT-ETH,BTC-ETH,BTC-BNB,ETH-BNB,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-,BNB-",
        fees: 0.1,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-ETH,BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["BNB"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: false,
        baseCurrencies: ["ETH"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "ETH-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH", "BNB"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-BNB,USDT-ETH,BTC-ETH,BTC-BNB,ETH-BNB,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-,BNB-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT", "ETH"],
        maxPairPerBase: 3,
        pairExcludes: "USDT-BTC,USDT-ETH,BTC-ETH,UP,DOWN",
        pairIncludes: "BTC-,USDT-,ETH-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN",
        pairIncludes: "BTC-,USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC", "USDT"],
        maxPairPerBase: 4,
        pairExcludes: "USDT-BTC,UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-,USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 5,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 6,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 7,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 8,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 9,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BUSD"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BUSD-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USDT-",
        fees: 0.1,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "huobi",
        compounding: false,
        baseCurrencies: ["USDT"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN,1L,2L,3L,1S,2S,3S",
        pairIncludes: "USDT-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "BTC-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["USD"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "USD-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: false,
        baseCurrencies: ["EUR"],
        maxPairPerBase: 10,
        pairExcludes: "UP,DOWN",
        pairIncludes: "EUR-",
        fees: 0.2,
    },
    {
        exchange: "binance",
        compounding: true,
        manualPairs: true,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 1,
        pairExcludes: "",
        pairIncludes: "-",
        fees: 0.1,
    },
    {
        exchange: "mex_gunthy",
        compounding: true,
        manualPairs: true,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 1,
        pairExcludes: "",
        pairIncludes: "-",
        fees: 0.1,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: true,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 1,
        pairExcludes: "",
        pairIncludes: "-",
        fees: 0.1,
    },
    {
        exchange: "kucoin",
        compounding: true,
        manualPairs: true,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 1,
        pairExcludes: "",
        pairIncludes: "-",
        fees: 0.1,
    },
    {
        exchange: "huobi",
        compounding: true,
        manualPairs: true,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 1,
        pairExcludes: "",
        pairIncludes: "-",
        fees: 0.2,
    },
    {
        exchange: "kraken",
        compounding: true,
        manualPairs: true,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 1,
        pairExcludes: "",
        pairIncludes: "-",
        fees: 0.2,
    },
    {
        exchange: "binanceus",
        compounding: true,
        manualPairs: true,
        baseCurrencies: ["BTC"],
        maxPairPerBase: 1,
        pairExcludes: "",
        pairIncludes: "-",
        fees: 0.1,
    },
];

void (async function buildAC() {
    const overridesCompounding = " " + (await minify("src/compounding/overridesFunction.js", options)).slice(0, -1);
    const overridesNoCompounding = " " + (await minify("src/noCompounding/overridesFunction.js", options)).slice(0, -1);
    const overridesCompoundingManualPairs = " " + (await minify("src/compounding_manual-pairs/overridesFunction.js", options)).slice(0, -1);
    const balanceTracker = " " + (await minify("src/compounding/balanceTracker.js", options)).slice(0, -1);
    const baseValueHistory = " " + (await minify("src/compounding/baseValueHistory.js", options)).slice(0, -1);

    outputVariations.forEach((item) => {
        const modifiedConfig = JSON.parse(JSON.stringify(defaultConfig));
        const compatibleLowPeriod = item.exchange === 'kraken' ? 'const lowPeriod=5' : 'const lowPeriod=3'
        const mvtsDefault = "MIN_VOLUME_TO_SELL:base==='USDT'||base==='BUSD'||base==='USDC'||base==='USD'||base==='EUR'?10:base==='BTC'?2e-4:base==='ETH'?.005:base==='BNB'?.05:2e-4"
        const mvtsKraken = "MIN_VOLUME_TO_SELL:base==='USDT'||base==='BUSD'||base==='USDC'||base==='USD'||base==='EUR'?60:base==='BTC'?0.001:base==='ETH'?.005:base==='BNB'?.05:2e-4"
        const compatibleMvts = item.exchange === 'kraken' ? mvtsKraken : mvtsDefault
        const exchangeDir = `build/${item.exchange}`
        let dir
        if (item.manualPairs){
            dir = `build/${item.exchange}/compounding_manual-pairs`;
        }
        else {  
            dir = `build/${item.exchange}/${item.maxPairPerBase * item.baseCurrencies.length}pairs_${item.baseCurrencies.join("-")}_${item.compounding && !item.manualPairs ? "compounding_auto-pairs" : !item.compounding && !item.manualPairs ? "noCompounding_auto-pairs" : "compounding_manual-pairs"}`;
        }
        if (!fs.existsSync(exchangeDir)) {
            fs.mkdirSync(exchangeDir);
        }
        if (!fs.existsSync(dir)) {
            fs.mkdirSync(dir);
        }

        const exchangeSettings = {
            key: "dum...",
            secret: "dum...",
            masterkey: "dum...",
            mastersecret: "dum...",
            delay: item.exchange === 'kraken' ? 5 : 0,
            market: "spot",
            isEncrypted: false,
            includeCoins: "",
            filteredBase: "",
            filteredQuote: "",
            autoPairs: false,
            tick_interval: 30,
            tick_time: false,
            TRADING_FEES: item.fees,
        };

        modifiedConfig.exchanges[item.exchange] = exchangeSettings;
        const modifiedAutoconfigTemplate = item.compounding && !item.manualPairs ? JSON.parse(JSON.stringify(defaultAutoconfig)) : !item.compounding && !item.manualPairs ? JSON.parse(JSON.stringify(defaultAutoconfigNoCompounding)) : JSON.parse(JSON.stringify(defaultAutoconfigManualPairs));

        const renameKeys = (keysMap, obj) =>
            Object.keys(obj).reduce(
                (acc, key) => ({
                    ...acc,
                    ...{ [keysMap[key] || key]: obj[key] }
                }),
                {}
            );
        const newKeys = { "addPairs": `addPairs_${item.exchange}`, "manageOverrides": `manageOverrides_${item.exchange}`, "removePairs": `removePairs_${item.exchange}` };
        const modifiedAutoconfig = renameKeys(newKeys, modifiedAutoconfigTemplate);

        Object.keys(modifiedAutoconfig).forEach((element) => {
            job = modifiedAutoconfig[element];
            job.pairs.exclude = item.pairExcludes;
            job.pairs.include = item.pairIncludes;
            job.pairs.maxPairs = item.baseCurrencies.length * item.maxPairPerBase;
            //job.pairs.exchange = item.exchange;

            if (item.compounding && !item.manualPairs) {
                if (element.includes("addPairs")) {
                    job.overrides.$MAX_PAIR_PER_BASE = item.maxPairPerBase;
                    if (item.exchange === "huobi") {
                        delete job.filters.spread;
                    }
                } else if (element.includes("manageOverrides")) {
                    job.setPairVariable.newOverrides = overridesCompounding;
                    job.overrides.TOTAL_BASE_VALUE = balanceTracker;
                    job.overrides.BASE_VALUE_HISTORY = baseValueHistory;
                }
            }
            else if (item.compounding && item.manualPairs) {
                if (element.includes("manageOverrides")) {
                    job.setPairVariable.newOverrides = overridesCompoundingManualPairs;
                    job.overrides.TOTAL_BASE_VALUE = balanceTracker;
                    job.overrides.BASE_VALUE_HISTORY = baseValueHistory;
                }
            }
            else {
                if (element.includes("addPairs")) {
                    job.overrides.$MAX_PAIR_PER_BASE = item.maxPairPerBase;
                } else if (element.includes("manageOverrides")) {
                    job.setPairVariable.newOverrides = overridesNoCompounding;
                }
            }
        });

        fs.writeFileSync(dir + "/config.js", JSON.stringify(modifiedConfig, null, 4));
        fs.writeFileSync(dir + "/autoconfig.json", JSON.stringify(modifiedAutoconfig, null, 4).replace(/binance/g, item.exchange).replace('const lowPeriod=3', compatibleLowPeriod).replace(mvtsDefault, compatibleMvts));
        if (!item.compounding) {
            fs.copyFileSync("src/noCompounding/extra_instructions.txt", dir + "/extra_instructions.txt");
        }
        if (item.manualPairs) {
            fs.copyFileSync("src/compounding_manual-pairs/extra_instructions.txt", dir + "/extra_instructions.txt");
        }
    });

    console.log('Done. Get your configs in the build folder.')
})();
