(function handleOverrides(data) {
    /* variable declarations */
    const base = data.pairName.split('-')[0];
    /* failsafe set of overrides to return */
    let overrides = {
        PERIOD: data.pair.whatstrat.PERIOD,
        TRADING_LIMIT: data.pair.whatstrat.TRADING_LIMIT,
        GRID_MULTIPLIER: data.pair.whatstrat.GRID_MULTIPLIER,
        STOP_AFTER_SELL: data.pair.whatstrat.STOP_AFTER_SELL,
        BUY_ENABLED: data.pair.whatstrat.BUY_ENABLED,
        NEED_PREPROCESSING: data.pair.whatstrat.NEED_PREPROCESSING,
        NEED_POSTPROCESSING: data.pair.whatstrat.NEED_POSTPROCESSING,
        START_CONT_TRADING: data.pair.whatstrat.START_CONT_TRADING,
        BAG_SIZE: data.pair.whatstrat.BAG_SIZE || 'none',
        BAG_VALUE: data.pair.whatstrat.BAG_VALUE || 'none',
        MIN_VOLUME_TO_SELL: base === 'USDT' || base === 'BUSD' || base === 'USDC' || base === 'USD' || base === 'EUR' ? 10 : base === 'BTC' ? 0.0002 : base === 'ETH' ? 0.005 : base === 'BNB' ? 0.05 : 0.0002
    };
    const ABP = data.pair.ABP;
    const bid = data.pair.Bid;
    const ask = data.pair.Ask;
    const atr = data.pair.atr;
    const fastSMA = data.pair.FAST_SMA;
    const slowSMA = data.pair.SLOW_SMA;
    const stoch = data.pair.STOCH_K;
    const needPreprocessing = data.pair.whatstrat.NEED_PREPROCESSING;
    const needPostProcessing = data.pair.whatstrat.NEED_POSTPROCESSING;
    const buyEnabled = data.pair.whatstrat.BUY_ENABLED;
    const quoteBalance = data.pair.quoteBalance;
    const howManyTL = parseFloat(data.pair.howManyTL);
    const maxBuyCount = parseFloat(data.pair.whatstrat.MAX_BUY_COUNT);
    const tlMultiplier = parseFloat(data.pair.whatstrat.TL_MULTIPLIER);
    const mvts = parseFloat(overrides.MIN_VOLUME_TO_SELL);
    const keepQuote = parseFloat(data.pair.whatstrat.KEEP_QUOTE);
    const period = parseFloat(data.pair.whatstrat.PERIOD);
    const highPeriod = 15;
    const lowPeriod = 3;
    const candleTimestamp0 = parseFloat(data.pair.candles.close[0].timestamp);
    const candleTimestamp1 = parseFloat(data.pair.candles.close[1].timestamp);
    const gotHighPeriodCandles = Math.max(candleTimestamp0, candleTimestamp1) - Math.min(candleTimestamp0, candleTimestamp1) > 600000;
    const notEnoughCandles = typeof data.pair.candlesclose === 'undefined' ? true : data.pair.candlesclose.length < 150;   
    const stopAfterSell = data.pair.whatstrat.STOP_AFTER_SELL;
    const pairFunds = parseFloat(data.pair.whatstrat.PAIR_FUNDS);
    const gotBag = overrides.BAG_SIZE !== 'none' && parseFloat(overrides.BAG_SIZE) > mvts ? true : false;
    const quitPct = 3.5;
    const quitTarget = (ABP * (1 - (quitPct / 100)));
    const balanceSettings = {
        maxNumberOfPairs: parseFloat(data.pair.whatstrat.$MAX_PAIR_PER_BASE) || 4,
        rapidTradeCount: parseFloat(data.pair.whatstrat.START_PERIOD_CHANGE) || parseFloat(data.pair.whatstrat.START_CONT_TRADING) || 3,
    };
    const useTrend = data.pair.whatstrat.TREND_OPEN || false;
    const useTrendAll = data.pair.whatstrat.TREND_OPEN || data.pair.whatstrat.TREND_BLOCK_DCA || data.pair.whatstrat.TREND_LOWER_DCA || false;
    let sentiment = 0;
    if (typeof data.pair.trendCheck !== 'undefined') {
		if (typeof data.pair.trendCheck.sentiment !== 'undefined') {
            sentiment = data.pair.trendCheck.sentiment;
            if (sentiment < 1 && useTrendAll) {
                overrides.START_CONT_TRADING = 4;
            }
            else if (sentiment > 0 && useTrendAll) {
                overrides.START_CONT_TRADING = 99;
            }
        }
	}

    /* functions used in strategy steps below */
    function setGridMultiplier(minimumMultiplier) {
        const defaultMultiplier = 1;

        if (!data.pair.candleshigh || !data.pair.candleslow || !data.pair.whatstrat) {
            overrides.GRID_MULTIPLIER = defaultMultiplier;
            return;
        }
        if (data.pair.candleshigh.length < 1 || data.pair.candleslow.length < 1) {
            overrides.GRID_MULTIPLIER = defaultMultiplier;
            return;
        }
        const candleshigh = data.pair.candleshigh;
        const candleslow = data.pair.candleslow;
        const highestPrice = Math.max(...candleshigh);
        const lowestPrice = Math.min(...candleslow);

        const totalSpread = (((highestPrice - lowestPrice) / bid) * 100);
        const cappedSpread = totalSpread > 100 ? 100 : totalSpread;
                
        const newMultiplier = parseFloat(
            Math.max(
                defaultMultiplier,
                minimumMultiplier + (cappedSpread / 100)
            )
        );
        overrides.GRID_MULTIPLIER = newMultiplier;
    }

    function setPeriod(value) {
        overrides.PERIOD = value;
    }

    function setStopAfterSell(value) {
        overrides.STOP_AFTER_SELL = value;
    }

    function setNeedPreProcesing(value) {
        overrides.NEED_PREPROCESSING = value;
    }

    function setNeedPostProcesing(value) {
        overrides.NEED_POSTPROCESSING = value;
    }

    function setBagSize() {
        if ((quoteBalance - keepQuote) * bid < mvts){
            overrides.BAG_SIZE = 'none';
        }
        else {
            if ((quoteBalance - keepQuote) * ABP > 0){
                overrides.BAG_SIZE = (quoteBalance - keepQuote) * ABP;
                overrides.BAG_VALUE = (quoteBalance - keepQuote) * bid;
            }
            else {
                overrides.BAG_SIZE = 'none';
            }
        }
    }

    function reverseCompound (balancePerPair) { 
        /* calculates initial trading limit, considering available balance, max buy count and tl multiplier */
        let divideBy = 1; 

        for (var i = 0; i < maxBuyCount; i++) {
            if (i > 0){
                divideBy = divideBy + Math.pow(tlMultiplier, i)
            }
        }
        const result = balancePerPair / divideBy;
        return result;
    }

    function setTradingLimit() {
        /* sets initial trading limit that fits the tl compounding settings */
        const balancePerPair = pairFunds * 0.99;
        const tl = reverseCompound(balancePerPair);
        if (tl > mvts){
            overrides.TRADING_LIMIT = tl.toPrecision(5);
        }
        else {
            overrides.TRADING_LIMIT = mvts * 1.1;
        }
    }

    function checkFreePairSlots() {
        /* checks if a pair can start trading without exceeding the number of pairs slots for its base currency */
        const maxSameBase = balanceSettings.maxNumberOfPairs;
        let pairsQueue = [];
        let pairsActive = [];
    
        Object.keys(data.config.pairs.binance).forEach(pair => {
            if (pair.split('-')[0] === base) {
                if (data.config.pairs.binance[pair].override.NEED_PREPROCESSING === true){
                    pairsQueue.push(pair);
                }
                else if (data.config.pairs.binance[pair].override.NEED_PREPROCESSING === false){
                    pairsActive.push(pair);
                }
            }
        });
    
        const freeSlots = maxSameBase - Math.max(pairsActive.length, maxSameBase);
        const pairsToAdd = pairsQueue.slice(0, freeSlots);
    
        if (pairsToAdd.indexOf(data.pairName) > -1 || pairsQueue.length + pairsActive.length < maxSameBase + 1) {
            return true;
        }
        else {
            return false;
        }
    }

    /* Steps to manage strategy settings overrides */

    /* save current bag size for use in total base balance calculation outside of this function */
    setBagSize();

    /* mark stale pair for removal */
    if (useTrend && sentiment !== 2 && !gotBag){
        setStopAfterSell(true);
        return overrides;
    }

    /* Post processing steps. After selling a bag, before removing it */
    /* Change to higher period to evaluate the pair again */
    if (needPostProcessing && howManyTL < 1 && !gotHighPeriodCandles && period !== highPeriod) {
        setPeriod(highPeriod);
        return overrides;
    }
    /* Do checks on high period, then discard or reactivate pair */
    else if (needPostProcessing && howManyTL < 1 && gotHighPeriodCandles && period === highPeriod) {
        
        const hasLowATR = 100 * (atr / bid) < 0.5;
        const hasHighStoch = stoch > 65;
        const hasHighOrderbookSpread = 100 * ((ask - bid) / bid) > 0.25;

        /* conditions to continue trading the pair */
        if ((bid > slowSMA && fastSMA > slowSMA && !hasLowATR && !hasHighStoch) || (useTrend && sentiment === 2)){
            setPeriod(lowPeriod);
            setTradingLimit();
            setNeedPreProcesing(true);
            setNeedPostProcesing(false);
            setStopAfterSell(false);
            overrides.BUY_ENABLED = false;
            return overrides;
        }

        /* conditions to discard the pair */
        if (bid < slowSMA || fastSMA < slowSMA || hasHighOrderbookSpread || hasHighStoch || hasLowATR) {
            setStopAfterSell(true);
            setNeedPostProcesing(false);
        }
        
        return overrides;
    }
    /* We must still be waiting for period change to take effect. return defaults */
    else if (needPostProcessing && howManyTL < 1) {
        return overrides;
   }

    /* Pre processing steps, once after adding a pair to either trade or discard it, and once when changing period */
    if (needPreprocessing && !buyEnabled){
        if (notEnoughCandles || (useTrend && sentiment !== 2)){
            setStopAfterSell(true);
        }
        else if ((bid > slowSMA && fastSMA > slowSMA && checkFreePairSlots() === true) || (useTrend && sentiment === 2 && checkFreePairSlots() === true)){
            overrides.BUY_ENABLED = true;
            setPeriod(lowPeriod);
            setTradingLimit();
        }
        else {
            setStopAfterSell(true);
        }
        
        setGridMultiplier(1.2);
        setNeedPreProcesing(false);
        return overrides;
    }
    else if (needPreprocessing && buyEnabled && gotBag){
        /* this happens after changing period from low to high */
        if (period === lowPeriod){
            setGridMultiplier(1.2);
        }
        else if (period === highPeriod){
            setGridMultiplier(0.8);    
        }

        setNeedPreProcesing(false);
        return overrides;
    }

    /* handle period related settings */
    /* initial switch to 15m */
    if (howManyTL > balanceSettings.rapidTradeCount - 1 && period == lowPeriod) {
        setPeriod(highPeriod);
        setNeedPreProcesing(true);
    }
    /* change back to 1m because apparently we sold */
    else if (howManyTL < 2 && period == highPeriod && !stopAfterSell) {
        setPeriod(lowPeriod);
        setNeedPreProcesing(true);
    }

    /* handle stopAfterSell, mark pairs for evaluation on different timeframe after selling bag */
    if (bid < quitTarget && !stopAfterSell && howManyTL > 1 && (!useTrend || (useTrend && sentiment < 2)) ) {
        setStopAfterSell(true);
        setNeedPostProcesing(true);
    }
    else if (100 * ((ask - bid) / bid) > 0.35 && !stopAfterSell && howManyTL > 1 && (!useTrend || (useTrend && sentiment < 2))) {
        setStopAfterSell(true);
        setNeedPostProcesing(true);
    }
    else if (100 * (atr / bid) < 0.25 && period == lowPeriod && !stopAfterSell && howManyTL > 1 && (!useTrend || (useTrend && sentiment < 2))) {
        setStopAfterSell(true);
        setNeedPostProcesing(true);
    }
    /* return modified overrides, will get written to config.js if there are any changes */
    return overrides;
})(this)